==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/server/thread/ResinThreadPoolExecutor.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.thread;

import com.caucho.util.L10N;
import com.caucho.util.ThreadPool;

import java.util.concurrent.Executor;
import java.util.logging.Logger;

/**
 * A generic pool of threads available for Alarms and Work tasks.
 */
public class ResinThreadPoolExecutor implements Executor {
  private static final L10N L = new L10N(ResinThreadPoolExecutor.class);
  private static final Logger log
    = Logger.getLogger(ResinThreadPoolExecutor.class.getName());

  private static ResinThreadPoolExecutor _service
    = new ResinThreadPoolExecutor();
    
  private ThreadPool _threadPool = ThreadPool.getThreadPool();

  private ResinThreadPoolExecutor()
  {
  }

  public static ResinThreadPoolExecutor getThreadPool()
  {
    return _service;
  }

  //
  // java.util.concurrent
  //

  public void execute(Runnable task)
  {
    if (task == null)
      throw new NullPointerException();
    
    _threadPool.schedule(task);
  }

  /**
   * Resets the thread pool, letting old threads drain.
   */
  public void stopEnvironment(ClassLoader env)
  {
    _threadPool.closeEnvironment(env);
  }

  public String toString()
  {
    return "ResinThreadPoolExecutor[]";
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/server/thread/ResinThreadPoolExecutor.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.thread;

import com.caucho.env.thread.ThreadPool;
import com.caucho.util.L10N;

import java.util.concurrent.Executor;
import java.util.logging.Logger;

/**
 * A generic pool of threads available for Alarms and Work tasks.
 */
public class ResinThreadPoolExecutor implements Executor {
  private static final L10N L = new L10N(ResinThreadPoolExecutor.class);
  private static final Logger log
    = Logger.getLogger(ResinThreadPoolExecutor.class.getName());

  private static ResinThreadPoolExecutor _service
    = new ResinThreadPoolExecutor();
    
  private ThreadPool _threadPool = ThreadPool.getThreadPool();

  private ResinThreadPoolExecutor()
  {
  }

  public static ResinThreadPoolExecutor getThreadPool()
  {
    return _service;
  }

  //
  // java.util.concurrent
  //

  public void execute(Runnable task)
  {
    if (task == null)
      throw new NullPointerException();
    
    _threadPool.schedule(task);
  }

  /**
   * Resets the thread pool, letting old threads drain.
   */
  public void stopEnvironment(ClassLoader env)
  {
    _threadPool.closeEnvironment(env);
  }

  public String toString()
  {
    return "ResinThreadPoolExecutor[]";
  }
}
